@@ -59,7 +59,7 @@ func (r *mockDevRunner) Prune(context.Context, io.Writer) error {
 	return nil
 }
 
-func (r *mockDevRunner) Cleanup(context.Context, io.Writer, bool, manifest.ManifestListByConfig) error {
+func (r *mockDevRunner) Cleanup(context.Context, io.Writer, bool, manifest.ManifestListByConfig, string) error {
 	r.calls = append(r.calls, "Cleanup")
 	return nil
 }
@@ -151,7 +151,7 @@ func (m *mockConfigChangeRunner) Render(ctx context.Context, out io.Writer, buil
 	return manifest.ManifestListByConfig{}, nil
 }
 
-func (m *mockConfigChangeRunner) Cleanup(context.Context, io.Writer, bool, manifest.ManifestListByConfig) error {
+func (m *mockConfigChangeRunner) Cleanup(context.Context, io.Writer, bool, manifest.ManifestListByConfig, string) error {
 	return nil
 }
 
