@@ -49,7 +49,7 @@ func cmdModulesList() *cobra.Command {
 func listModules(ctx context.Context, out io.Writer) error {
 	return modules.PrintModulesList(ctx, out, inspect.Options{
 		Filename:       inspectFlags.filename,
-		RepoCacheDir:   inspectFlags.repoCacheDir,
+		RemoteCacheDir: inspectFlags.remoteCacheDir,
 		OutFormat:      inspectFlags.outFormat,
 		ModulesOptions: inspect.ModulesOptions{IncludeAll: modulesFlags.includeAll},
 	})
