@@ -248,7 +248,7 @@ type TestStructure struct {
 
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.same, diff == "")
 			if test.same != (diff == "") {
-				t.Errorf(diff)
+				t.Error(diff)
 			}
 		})
 	}
@@ -284,7 +284,7 @@ func TestCompareSchemas(t *testing.T) {
 			t.CheckNoError(err)
 			t.CheckDeepEqual(test.a == test.b, diff == "")
 			if diff != "" && test.a == test.b {
-				t.Errorf(diff)
+				t.Error(diff)
 			}
 		})
 	}
