@@ -61,6 +61,11 @@ var tests = []struct {
 		pods:        []string{"getting-started"},
 		targetLog:   "Hello world!",
 	},
+	{
+		description: "ko",
+		dir:         "examples/ko",
+		deployments: []string{"ko"},
+	},
 	{
 		description: "nodejs",
 		dir:         "examples/nodejs",
@@ -141,6 +146,13 @@ var tests = []struct {
 		dir:         "examples/custom",
 		pods:        []string{"getting-started-custom"},
 	},
+	{
+		description: "helm templating charPath",
+		dir:         "testdata/helm",
+		args:        []string{"-p", "helm-templating-charPath"},
+		deployments: []string{"skaffold-helm"},
+		env:         []string{"FOO=skaffold-helm"},
+	},
 	// TODO(#8811): Enable this test when issue is solve.
 	// {
 	// 	description: "buildpacks Go",
