@@ -37,9 +37,8 @@ import (
 )
 
 var (
-	defaultStatusCheckDeadline = 10 * time.Minute
-	defaultPollPeriod          = 1000 * time.Millisecond
-	defaultReportStatusTime    = 5 * time.Second
+	defaultPollPeriod       = 1000 * time.Millisecond
+	defaultReportStatusTime = 5 * time.Second
 )
 
 type Monitor struct {
@@ -51,15 +50,17 @@ type Monitor struct {
 	statusCheckDeadline time.Duration
 	pollPeriod          time.Duration
 	reportStatusTime    time.Duration
+	tolerateFailures    bool
 }
 
-func NewMonitor(labeller *label.DefaultLabeller, clientOptions []option.ClientOption) *Monitor {
+func NewMonitor(labeller *label.DefaultLabeller, clientOptions []option.ClientOption, statusCheckDeadline time.Duration, tolerateFailures bool) *Monitor {
 	return &Monitor{
 		labeller:            labeller,
 		clientOptions:       clientOptions,
-		statusCheckDeadline: defaultStatusCheckDeadline,
+		statusCheckDeadline: statusCheckDeadline,
 		pollPeriod:          defaultPollPeriod,
 		reportStatusTime:    defaultReportStatusTime,
+		tolerateFailures:    tolerateFailures,
 	}
 }
 
@@ -82,6 +83,8 @@ func (s *Monitor) check(ctx context.Context, out io.Writer) error {
 			sub = &runServiceResource{path: resource.String()}
 		case typeJob:
 			sub = &runJobResource{path: resource.String()}
+		case typeWorkerPool:
+			sub = &runWorkerPoolResource{path: resource.String()}
 		default:
 			return fmt.Errorf("unable to monitor resource. Unknown type %s", resource.Type())
 		}
@@ -97,7 +100,7 @@ func (s *Monitor) check(ctx context.Context, out io.Writer) error {
 		wg.Add(1)
 		go func(resource *runResource) {
 			defer wg.Done()
-			resource.pollResourceStatus(cctx, s.statusCheckDeadline, s.pollPeriod, s.clientOptions, true)
+			resource.pollResourceStatus(cctx, s.statusCheckDeadline, s.pollPeriod, s.clientOptions, true, s.tolerateFailures)
 			c.markComplete()
 			res := resource.status
 			if res.ae.ErrCode != proto.StatusCode_STATUSCHECK_SUCCESS {
@@ -160,7 +163,7 @@ type runSubresource interface {
 	reportSuccess()
 }
 
-func (r *runResource) pollResourceStatus(ctx context.Context, deadline time.Duration, pollPeriod time.Duration, clientOptions []option.ClientOption, useGcpOptions bool) {
+func (r *runResource) pollResourceStatus(ctx context.Context, deadline time.Duration, pollPeriod time.Duration, clientOptions []option.ClientOption, useGcpOptions bool, tolerateFailures bool) {
 	ticker := time.NewTicker(pollPeriod)
 	defer ticker.Stop()
 	timeoutContext, cancel := context.WithTimeout(ctx, deadline+pollPeriod)
@@ -195,7 +198,7 @@ func (r *runResource) pollResourceStatus(ctx context.Context, deadline time.Dura
 			}
 			return
 		case <-ticker.C:
-			r.checkStatus(crClient)
+			r.checkStatus(crClient, tolerateFailures)
 			if r.completed {
 				return
 			}
@@ -223,7 +226,7 @@ func (r *runResource) ReportSinceLastUpdated() string {
 	return fmt.Sprintf("%s: %s", r.resource.Name(), curStatus.ae.Message)
 }
 
-func (r *runResource) checkStatus(crClient *run.APIService) {
+func (r *runResource) checkStatus(crClient *run.APIService, tolerateFailures bool) {
 	ready, err := r.sub.getTerminalStatus(crClient)
 	if err != nil {
 		r.updateStatus(err)
@@ -247,7 +250,11 @@ func (r *runResource) checkStatus(crClient *run.APIService) {
 		})
 
 	case "False":
-		r.completed = true
+		// If there is no failure toleration, update completed to true so that
+		// status monitoring finishes.
+		if !tolerateFailures {
+			r.completed = true
+		}
 		r.updateStatus(&proto.ActionableErr{
 			ErrCode: proto.StatusCode_STATUSCHECK_UNHEALTHY,
 			Message: fmt.Sprintf("%s failed to start: %v", r.resource.Type(), ready.Message),
@@ -261,7 +268,7 @@ func (r *runResource) checkStatus(crClient *run.APIService) {
 	}
 }
 
-// printResourceStatus prints resource statuses until all status check are completed or context is cancelled.
+// printResourceStatus prints resource statuses until all status checks are completed or context is cancelled.
 func (s *Monitor) printResourceStatus(ctx context.Context, out io.Writer, resources []*runResource) {
 	ticker := time.NewTicker(s.reportStatusTime)
 	defer ticker.Stop()
@@ -383,3 +390,36 @@ func (r *runJobResource) getTerminalStatus(crClient *run.APIService) (*run.Googl
 
 func (r *runJobResource) reportSuccess() {
 }
+
+type runWorkerPoolResource struct {
+	path           string
+	latestRevision string
+}
+
+func (r *runWorkerPoolResource) getTerminalStatus(crClient *run.APIService) (*run.GoogleCloudRunV1Condition, *proto.ActionableErr) {
+	call := crClient.Namespaces.Workerpools.Get(r.path)
+	res, err := call.Do()
+	if err != nil {
+		return nil, &proto.ActionableErr{
+			ErrCode: proto.StatusCode_STATUSCHECK_KUBECTL_CLIENT_FETCH_ERR,
+			Message: fmt.Sprintf("Unable to check Cloud Run status: %v", err),
+		}
+	}
+	// find the ready condition
+	var ready *run.GoogleCloudRunV1Condition
+
+	// If the status is still showing the old generation, treat it the
+	// same as no status being set.
+	if res.Status.ObservedGeneration == res.Metadata.Generation {
+		for _, cond := range res.Status.Conditions {
+			if cond.Type == "Ready" {
+				ready = cond
+				break
+			}
+		}
+	}
+	r.latestRevision = res.Status.LatestCreatedRevisionName
+	return ready, nil
+}
+
+func (r *runWorkerPoolResource) reportSuccess() {}
