@@ -19,7 +19,7 @@ package kubernetes
 import (
 	"testing"
 
-	"github.com/GoogleContainerTools/skaffold/testutil"
+	"github.com/GoogleContainerTools/skaffold/v2/testutil"
 )
 
 func TestSupportedKubernetesFormats(t *testing.T) {
