@@ -19,8 +19,8 @@ package platform
 import (
 	"fmt"
 
-	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
-	"github.com/GoogleContainerTools/skaffold/proto/v1"
+	sErrors "github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/errors"
+	"github.com/GoogleContainerTools/skaffold/v2/proto/v1"
 )
 
 // UnknownPlatformCLIFlag specifies that the platform provided via CLI flag couldn't be parsed
