@@ -26,8 +26,8 @@ import (
 	cstorage "cloud.google.com/go/storage"
 	appsv1 "k8s.io/api/apps/v1"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/webhook/constants"
-	"github.com/GoogleContainerTools/skaffold/pkg/webhook/kubernetes"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/webhook/constants"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/webhook/kubernetes"
 )
 
 // UploadDeploymentLogsToBucket gets logs from d and uploads them to the bucket
